@@ -4,6 +4,8 @@
 # --> Configuration class handles Cognicept configuration
 
 from dotenv import dotenv_values
+from dotenv import load_dotenv
+from dotenv import find_dotenv
 from pathlib import Path
 from Crypto.PublicKey import RSA
 import subprocess
@@ -27,24 +29,23 @@ class Configuration:
         object.config_path = os.path.expanduser(path)
         object.env_path = object.config_path + "runtime.env"
         file = Path(object.env_path)
-        
+
         if ((not file.exists()) or (file.is_dir())):
             print("Configuration file `" + object.env_path + "` does not exist.")
             return False
-        
-        object.config = dotenv_values(file)
 
+        #object.config = dotenv_values(dotenv_path=file.name) if sys.version_info.minor > 5 else dotenv_values(dotenv_path=find_dotenv(), verbose=True)
+        object.config = dotenv_values(dotenv_path=object.env_path, verbose = True)
         if(len(object.config) == 0):
             print("Configuration file `" + object.env_path + "` is empty or could not be parsed.")
             return False
-
         object._config_loaded = True
         return True
 
     def configure(object, args):
         if(not object._config_loaded):
             return
-        
+
         if (not os.access(object.env_path, os.W_OK)):
             print("Error: You don't have writing permissions for `" + object.env_path + "`. Run as `sudo` or change file permissions.")
             return
@@ -64,7 +65,7 @@ class Configuration:
                 if matches is None:
                     print("Error: Key can be uppercase letters, digits, and the '_'. Try again.")
                     new_key = ""
-            
+
             new_value = ""
             while(new_value == ""):
                 new_value = input("Value: ")
@@ -94,24 +95,24 @@ class Configuration:
                     file.write(key + '=' + value + '\n')
         except IOError:
             print("Could not write into `" + object.env_path + "`. Please check write permission or run with `sudo`.")
-    
+
     def cognicept_login(object):
         print("Please enter your Cognicept credentials.")
-        
+
         username = input("Username: ")
-        try: 
-            password = getpass.getpass() 
-        except Exception as error: 
+        try:
+            password = getpass.getpass()
+        except Exception as error:
             print('Error when reading password.')
             return False
-        
+
         try:
             resp = requests.post(object.get_cognicept_api_uri() + 'user/login', json = {"username": username, "password": password}, timeout = 5)
             if resp.status_code != 200:
                 print('Login error: wrong credentials.')
                 return False
-            
-            object.config["COGNICEPT_JWT"] = resp.json()["access_token"]            
+
+            object.config["COGNICEPT_JWT"] = resp.json()["access_token"]
         except requests.exceptions.Timeout:
             print("Cognicept REST API error: time out.")
             return
@@ -123,7 +124,7 @@ class Configuration:
             raise SystemExit()
         object.save_config()
 
-        
+
 
         return True
 
@@ -259,4 +260,4 @@ class Configuration:
         if(not "COG_ENABLE_SSH_KEY_AUTH" in object.config):
             return False
         
-        return object.config["COG_ENABLE_SSH_KEY_AUTH"]
\ No newline at end of file
+        return object.config["COG_ENABLE_SSH_KEY_AUTH"]
